<?php
//Adds a box to the main column on the Post and Page edit screens.
 
function vimo_csbl_add_meta_box() {

	$screens = array( 'page' );

	foreach ( $screens as $screen ) {

		add_meta_box(
			'vimo_csbl_sectionid',
			__( 'Custom Sidebar Links', 'Vimo_CSBL'),
			'vimo_csbl_metabox',
			$screen,
			'side'
		);
	}
}
add_action( 'add_meta_boxes', 'vimo_csbl_add_meta_box' );


//Prints the box content.
function vimo_csbl_metabox( $post ) {

	// Add a nonce field so we can check for it later.
	wp_nonce_field( 'vimo_csbl_save_meta_box_data', 'vimo_csbl_meta_box_nonce' );

	/*
	 * Use get_post_meta() to retrieve an existing value
	 * from the database and use the value for the form.
	 */
	$menutitle = get_post_meta( $post->ID, 'vimo_csbl_title', true );


	echo '<div style="height: 400px; overflow-y: scroll;">';
	echo '<label for="vimo_csbl_menu_title">';
	echo '<h2 style="padding: 10px 0 0 0;"><b>Sidebar Menu Title</h2></b>';
	echo '<small>(If blank, page name will be used)</small>';
	echo '</label>';
	echo '<br /><input type="text" id="vimo_csbl_menu_title" name="vimo_csbl_menu_title" value="' . esc_attr( $menutitle ) . '" size="25" style="margin-top: 5px;" />';
	echo '<br /><br />';

	echo 'Select a menu or a list of pages below:';
	
	echo '<h2 style="padding-left: 0;"><b>Menus</b></h2>';	

	$menus = get_terms( 'nav_menu' );

	$selectedMenu = get_post_meta( $post->ID, 'vimo_csbl_menu', true );

	if( empty($menus) ) {
	
		echo 'No menus have been created yet.';

	} else { ?>

		<select name="menus" style="width: 95%;">
			
			<?php if( $selectedMenu ) { ?>
			
				<option value="<?php esc_attr_e( $selectedMenu ); ?>"><?php esc_html_e( $selectedMenu ); ?></option>
				
			<?php } ?>
				
			<option value="">---</option>
			
			<?php
			foreach( $menus as $menu ) {
				
				if( $menu->name != $selectedMenu ) { ?>
			  	
			  		<option value="<?php esc_attr_e( $menu->name ); ?>"><?php esc_html_e( $menu->name ); ?></option>
				
				<?php } ?>

			<?php } ?>
			

		</select>
		
	<?php }

	$enabledPosts = get_option( 'vimo_csbl_settings' );

	// we store data as an array, we need to unserialize it
    $selectedPages = maybe_unserialize( get_post_meta( $post->ID, 'vimo_csbl_selectedPages', true ) );

    // Nonce to verify intention later
    wp_nonce_field( 'save_quote_meta', 'custom_nonce' ); ?>

	    <h2 style="padding-left: 0; font-weight: bold;">Pages</h2>
		
		<?php
		$pages = get_pages(); 
	    foreach ( $pages as $page ) { ?>
	        <input id="page_<?php esc_attr_e( $page->ID ); ?>" type="checkbox" name="selectedPages[]" value="<?php esc_attr_e( $page->ID ); ?>" <?php if ( in_array( $page->ID, (array) $selectedPages) ) { ?> checked <?php } ?>/> <label for="page_<?php esc_attr_e( $page->ID ); ?>"><?php esc_html_e( $page->post_title ); ?></label> <br>

		<?php }

	if( is_array( $enabledPosts ) && in_array( 'post', $enabledPosts ) ) : ?>
		<hr />

		<h2 style="padding-left: 0; font-weight: bold;">Posts</h2>
		<ul style="margin: 0 0 15px 0;">
		<?php
		$cats = get_categories();
		foreach ($cats as $cat) {
		  echo "<li><em>".$cat->cat_name."</em>";
		  echo "<ul>";
		  query_posts('posts_per_page=-1&cat='.$cat->cat_ID);
		  while(have_posts()) {
		    the_post();
		    $category = get_the_category();
		    // Only display a post link once, even if it's in multiple categories
		    if ( $category[0]->cat_ID == $cat->cat_ID ) { ?>

		      	<input id="page_<?php the_ID(); ?>" type="checkbox" name="selectedPages[]" value="<?php the_ID(); ?>" <?php if ( in_array( get_the_ID(), (array) $selectedPages) ) { ?> checked <?php } ?>/> <label for="page_<?php the_ID(); ?>"><?php the_title(); ?></label> <br>

		    <?php }
		  }
		  echo "</ul>";
		  echo "</li>";
		}
		?>
		</ul>
	
	<?php
	endif;

	if( is_array( $enabledPosts ) ) :
		foreach( $enabledPosts as $post_type ) {
		  if ( in_array( $post_type, array('post','page','attachment') ) )
		    continue;
		  $pt = get_post_type_object( $post_type );

		$hasposts = get_posts( 'post_type=' . $post_type );
		if( $hasposts ) :
		
		  echo '<hr /><h2 style="padding-left: 0; font-weight: bold;">'. esc_html_e( $pt->labels->name ) . '</h2>';
		
		endif;

		  echo '<ul>';
		
		query_posts( 'post_type=' . $post_type . '&posts_per_page=-1' );
		 
		while( have_posts() ) {
		    the_post(); ?>
		  	<input id="page_<?php the_ID(); ?>" type="checkbox" name="selectedPages[]" value="<?php the_ID(); ?>" <?php if ( in_array( get_the_ID() , (array) $selectedPages) ) { ?> checked <?php } ?>/> <label for="page_<?php the_ID(); ?>"><?php the_title(); ?></label> <br>
		  <?php }
		  echo '</ul>';
		}
	endif;
	wp_reset_query();
	?>

</div>

    <?php
	//save the meta box action
	add_action( 'save_post', 'vimo_csbl_meta_save', 10, 2 );

}

// Saves the metabox info
function vimo_csbl_save_meta_box_data( $post_id ) {

	// Check if our nonce is set.
	if ( ! isset( $_POST['vimo_csbl_meta_box_nonce'] ) ) {
		return;
	}

	// Verify that the nonce is valid.
	if ( ! wp_verify_nonce( $_POST['vimo_csbl_meta_box_nonce'], 'vimo_csbl_save_meta_box_data' ) ) {
		return;
	}

	// If this is an autosave, our form has not been submitted, so we don't want to do anything.
	if ( defined( 'DOING_AUTOSAVE' ) && DOING_AUTOSAVE ) {
		return;
	}

	// Check the user's permissions.
	if ( isset( $_POST['post_type'] ) && 'page' == $_POST['post_type'] ) {

		if ( ! current_user_can( 'edit_page', $post_id ) ) {
			return;
		}

	} else {

		if ( ! current_user_can( 'edit_post', $post_id ) ) {
			return;
		}
	}

	/* OK, it's safe for us to save the data now. */

	if ( isset( $_POST['vimo_csbl_menu_title'] ) ) {
		
		// Sanitizing Menu Title text field before entering it to database
		$menuTitleField = sanitize_text_field( $_POST['vimo_csbl_menu_title'] );
		
		update_post_meta( $post_id, 'vimo_csbl_title', $menuTitleField );
		
	} else {
		return;
	}

	if ( isset( $_POST['menus'] ) ) {
		
		// Sanitizing Menu Select before entering it to database
		// ensuring that the only possible values are the menus that actually have been created on the site		
		$allMenus = get_terms( 'nav_menu' );

		$validMenuValues = array();
		foreach( $allMenus as $menuName ) {
			$validMenuValues[] = $menuName->name;
		}

		$menuSelect = sanitize_text_field( $_POST['menus'] );

		if( in_array( $menuSelect, $validMenuValues ) ) {
			update_post_meta( $post_id, 'vimo_csbl_menu', $menuSelect );
		} else {
			update_post_meta( $post_id, 'vimo_csbl_menu', '' );
		}
	
	} else {
		return;
	}

	if ( isset( $_POST['selectedPages'] ) ) {
		
		// Sanitizing the checkbox values of the pages or posts that have been selected. (IDs)
		// ensures that only integers are in the array
		$selectedIDs = array_map( intval, $_POST['selectedPages'] );

		update_post_meta( $post_id, 'vimo_csbl_selectedPages', $selectedIDs );
	
	} else {
		update_post_meta( $post_id, 'vimo_csbl_selectedPages', '' );
	}
}
add_action( 'save_post', 'vimo_csbl_save_meta_box_data' );