<?php
/**
* Plugin Name: Custom Sidebar Links
* Description: This plugin gives you the ability to add custom links or menus to the sidebar of any page.
* Version: 1.0.0
* Author: Vinny Moreira
* Author URI: http://vinnymoreira.com/
* License: GPL2
*/

// Block direct requests
if ( !defined('ABSPATH') )
	die('-1');

define( 'CSBL__PLUGIN_URL', plugin_dir_url( __FILE__ ) );
define( 'CSBL__PLUGIN_DIR', plugin_dir_path( __FILE__ ) );

include plugin_dir_path( __FILE__ ) . 'admin/metabox.php';
include plugin_dir_path( __FILE__ ) . 'admin/options.php';

class Vimo_CSBL_List_Pages_Widget extends WP_Widget {

    function __construct() {
        parent::__construct(
            'vimo_csbl_list_pages_widget',
            __('Custom Sidebar Links', 'vimo_csbl' ),
            array (
                'description' => __( 'Add custom links or menus to your sidebar.', 'vimo_csbl' )
            )
        );
    }
     
    function form( $instance ) {
		$childPages = isset($instance['child-pages']);
        ?>

        <p>
        	<input id="<?php echo $this->get_field_id('child-pages'); ?>" name="<?php echo $this->get_field_name('child-pages'); ?>" type="checkbox" value="1" <?php checked( '1', $childPages ); ?>/>
        	<label for="<?php echo $this->get_field_id('child-pages'); ?>"><?php _e('Enable default child pages?'); ?></label>
    	</p>

    <?php
    }
     
    function update( $new_instance, $old_instance ) {
        $instance = $old_instance;
        $instance[ 'child-pages' ] = strip_tags( $new_instance[ 'child-pages' ] );
        $instance['child-pages'] = strip_tags($new_instance['child-pages']);
        return $instance;
    }
     
    function widget( $args, $instance ) {
    	
		$enableChild = $instance['child-pages'];
    	$page_object = get_queried_object();
		$page_id = get_queried_object_id();
		$menuTitle = esc_attr( get_post_meta( $page_id, 'vimo_csbl_title', true ) );
		$selectedMenu = get_post_meta( $page_id, 'vimo_csbl_menu', true );
		$selectedPages = maybe_unserialize( get_post_meta($page_id, 'vimo_csbl_selectedPages', true) );

        extract( $args );
        echo $before_widget;
         
        // run a query if on a page
        if ( is_page() ) {

			if( !empty( $enableChild )  && !( $selectedMenu ) && !( $selectedPages )  ) {

				global $post;

				// Make sure we are on a page and that the page is a parent
				
				if ( $post->post_parent ) {
				
					$childpages = wp_list_pages( 'sort_column=menu_order&title_li=&child_of=' . $post->post_parent . '&echo=0' );
				
				} else {
				
					$childpages = wp_list_pages( 'sort_column=menu_order&title_li=&child_of=' . $post->ID . '&echo=0' );	 
				
				}
				
				if ( $childpages ) { ?>
					<aside id="vimo-csbl" class="widget vimo-csbl">
						<h3 class="widget-title"><?php if( $menuTitle ) : echo $menuTitle; else : the_title(); endif; ?></h3>
						<ul>
							<?php echo $childpages; ?>
						</ul>
					</aside>
				<?php }

			} else { ?>

				<aside id="vimo-csbl" class="widget vimo-csbl">
	        	
		        	<h3 class="widget-title"><?php if( $menuTitle ) : echo $menuTitle; else : the_title(); endif; ?></h3>

		        	<?php 
		        	if( $selectedMenu ) : ?>

			        	<?php wp_nav_menu( array('menu' => $selectedMenu )); ?>			        	

			        <?php else :
			     		
						if( $selectedPages ) :
						    foreach ( $selectedPages as $id ) {
						        echo '<ul>';
								echo '<li><a href="' . get_permalink( $id ) . '">' . get_the_title( $id ) . '</a></li>';
								echo '</ul>';
							}
						endif;	
			     	
			     	endif; ?>
		     	
	     		</aside>
				
			<?php 
			}
        }
    }
}

/**********************************************************************
function vimo_csbl_register_list_pages_widget() - registers the widget.
**********************************************************************/

function vimo_csbl_register_list_pages_widget() {
 
    register_widget( 'vimo_csbl_list_pages_widget' );
 
}
add_action( 'widgets_init', 'vimo_csbl_register_list_pages_widget' );

/*******************************************************************************************************
Shortcode [vimo_csbl] to display custom sidebar menu links from the content area of any page in wp-admin
*******************************************************************************************************/

function vimo_csbl_function() {

	$widget = new Vimo_CSBL_List_Pages_Widget();
	$enableChild = $widget->get_settings();
	$page_object = get_queried_object();
	$page_id = get_queried_object_id();
	$menuTitle = esc_attr( get_post_meta( $page_id, 'vimo_csbl_title', true ) );
	$selectedMenu = get_post_meta( $page_id, 'vimo_csbl_menu', true );
	$selectedPages = maybe_unserialize( get_post_meta( $page_id, 'vimo_csbl_selectedPages', true) );

	?>
	
	<?php if( !empty( $enableChild )  && !( $selectedMenu ) && !( $selectedPages )  ) {

		global $post;

		// Make sure we are on a page and that the page is a parent
		
		if ( $post->post_parent ) {
		
			$childpages = wp_list_pages( 'sort_column=menu_order&title_li=&child_of=' . $post->post_parent . '&echo=0' );
		
		} else {
		
			$childpages = wp_list_pages( 'sort_column=menu_order&title_li=&child_of=' . $post->ID . '&echo=0' );	 
		
		}
		
		if ( $childpages ) { ?>
			<div id="vimo-csbl" class="widget vimo-csbl">
				<h3 class="widget-title"><?php if( $menuTitle ) : echo $menuTitle; else : the_title(); endif; ?></h3>
				<ul>
					<?php echo $childpages; ?>
				</ul>
			</div>
		<?php }	

	} else { ?>

		<div id="vimo-csbl" class="widget vimo-csbl">
    	
        	<h3 class="widget-title"><?php if( $menuTitle ) : echo $menuTitle; else : the_title(); endif; ?></h3>

        	<?php 
        	if( $selectedMenu ) : ?>

	        	<?php wp_nav_menu( array('menu' => $selectedMenu )); ?>			        	

	        <?php else :
	     		
				if( $selectedPages ) :
				    foreach ( $selectedPages as $id ) {
				        echo '<ul>';
						echo '<li><a href="' . get_permalink( $id ) . '">' . get_the_title( $id ) . '</a></li>';
						echo '</ul>';
					}
				endif;	
	     	
	     	endif; ?>
     	
 		</div>
		
	<?php }
}

add_shortcode( 'vimo_csbl', 'vimo_csbl_function' );